@@ -12,6 +12,8 @@ SCORE ObjScorePS(const MSA &msa, SCORE MatchScore[] = 0);
 SCORE ObjScoreSP(const MSA &msa, SCORE MatchScore[] = 0);
 SCORE ObjScoreXP(const MSA &msa, const MSA &msa2);
 SCORE ObjScoreSPDimer(const MSA &msa);
+SCORE ObjScoreDP_Profs(const ProfPos *PA, const ProfPos *PB, unsigned uColCount,
+  SCORE MatchScore[] = 0);
 
 SCORE DiffObjScore(
   const MSA &msa1, const PWPath &Path1, const unsigned Edges1[], unsigned uEdgeCount1, 
